about summary refs log tree commit diff
path: root/src/libstd
diff options
context:
space:
mode:
authorJohn Simon <john@johnsoft.com>2014-04-13 17:23:17 -0400
committerJohn Simon <john@johnsoft.com>2014-04-13 17:42:00 -0400
commit133834084e7fb8efba6e9c25816b6d4de03007ff (patch)
tree9bcfc55d4f33fef20349df50aa2189b03b1ebf64 /src/libstd
parent2f790546504f869788f3c0e9585b51470773332f (diff)
downloadrust-133834084e7fb8efba6e9c25816b6d4de03007ff.tar.gz
rust-133834084e7fb8efba6e9c25816b6d4de03007ff.zip
Replace 'region' with 'lifetime' in a few transmute function names
Diffstat (limited to 'src/libstd')
-rw-r--r--src/libstd/cast.rs14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/libstd/cast.rs b/src/libstd/cast.rs
index de9e916c746..f9f9e395f2e 100644
--- a/src/libstd/cast.rs
+++ b/src/libstd/cast.rs
@@ -63,9 +63,9 @@ pub unsafe fn transmute<L, G>(thing: L) -> G {
 #[inline]
 pub unsafe fn transmute_mut<'a,T>(ptr: &'a T) -> &'a mut T { transmute(ptr) }
 
 /// Coerce a reference to have an arbitrary associated region.
 #[inline]
-pub unsafe fn transmute_region<'a,'b,T>(ptr: &'a T) -> &'b T {
+pub unsafe fn transmute_lifetime<'a,'b,T>(ptr: &'a T) -> &'b T {
     transmute(ptr)
 }
 
@@ -75,28 +75,28 @@ pub unsafe fn transmute_mut_unsafe<T>(ptr: *T) -> *mut T {
     transmute(ptr)
 }
 
 /// Coerce a mutable reference to have an arbitrary associated region.
 #[inline]
-pub unsafe fn transmute_mut_region<'a,'b,T>(ptr: &'a mut T) -> &'b mut T {
+pub unsafe fn transmute_mut_lifetime<'a,'b,T>(ptr: &'a mut T) -> &'b mut T {
     transmute(ptr)
 }
 
 /// Transforms lifetime of the second pointer to match the first.
 #[inline]
 pub unsafe fn copy_lifetime<'a,S,T>(_ptr: &'a S, ptr: &T) -> &'a T {
-    transmute_region(ptr)
+    transmute_lifetime(ptr)
 }
 
 /// Transforms lifetime of the second pointer to match the first.
 #[inline]
 pub unsafe fn copy_mut_lifetime<'a,S,T>(_ptr: &'a mut S, ptr: &mut T) -> &'a mut T {
-    transmute_mut_region(ptr)
+    transmute_mut_lifetime(ptr)
 }
 
 /// Transforms lifetime of the second pointer to match the first.
 #[inline]
 pub unsafe fn copy_lifetime_vec<'a,S,T>(_ptr: &'a [S], ptr: &T) -> &'a T {
-    transmute_region(ptr)
+    transmute_lifetime(ptr)
 }
@@ -63,9 +63,9 @@ pub unsafe fn transmute<L, G>(thing: L) -> G {
 pub unsafe fn transmute_mut<'a,T>(ptr: &'a T) -> &'a mut T { transmute(ptr) }
 
-/// Coerce a reference to have an arbitrary associated region.
+/// Coerce a reference to have an arbitrary associated lifetime.
 #[inline]
@@ -75,28 +75,28 @@ pub unsafe fn transmute_mut_unsafe<T>(ptr: *T) -> *mut T {
 }
 
-/// Coerce a mutable reference to have an arbitrary associated region.
+/// Coerce a mutable reference to have an arbitrary associated lifetime.
 #[inline]